@@ -63,7 +63,7 @@ class CenterColumnStudyReactor(paramak.Reactor):
 
         super().__init__([])
 
-        self.method = 'trelis'
+        self.method = 'cubit'
 
         self.inner_bore_radial_thickness = inner_bore_radial_thickness
         self.inboard_tf_leg_radial_thickness = inboard_tf_leg_radial_thickness
